@@ -4,8 +4,10 @@ from jovian.utils.records import (log_hyperparams, log_metrics, log_dataset,
                                   log_git, reset, get_records)
 from jovian.utils.slack import notify
 from jovian.utils.submit import submit
+from jovian.utils.colab import set_colab_file_id as set_colab_id
 from jovian.utils.configure import reset_config, configure
 from jovian.utils.initialize import _initialize_jovian
 from jovian.utils.misc import version
+from jovian.utils.rcfile import set_project
 
 _initialize_jovian()
